@@ -38,8 +38,6 @@
 #include <KSharedConfig>
 #include <KPackage/PackageLoader>
 
-#include <Plasma/Theme>
-
 #include <algorithm>
 #include <cstring>
 #include <iostream>
@@ -49,8 +47,7 @@ using namespace CuttleFish;
 static QTextStream cout(stdout);
 
 IconModel::IconModel(QObject *parent) :
-    QAbstractListModel(parent),
-    m_theme(QStringLiteral("breeze"))
+    QAbstractListModel(parent)
     , m_loading(false)
 {
     m_roleNames.insert(FileName, "fileName");
@@ -63,20 +60,6 @@ IconModel::IconModel(QObject *parent) :
     m_roleNames.insert(Theme, "iconTheme");
     m_roleNames.insert(Type, "type");
 
-    connect(this, &IconModel::categoryChanged, this, &IconModel::load);
-    KConfigGroup cg(KSharedConfig::openConfig("cuttlefishrc"), "CuttleFish");
-    const QString themeName = cg.readEntry("theme", "default");
-
-    Plasma::Theme theme;
-//     qDebug() << "Setting Plasma theme" << themeName;
-    theme.setUseGlobalSettings(false);
-    theme.setThemeName(themeName); // needs to happen after setUseGlobalSettings, since that clears themeName
-
-    QList<KPluginMetaData> themepackages = KPackage::PackageLoader::self()->listPackages(QString(), "plasma/desktoptheme");
-    foreach (const KPluginMetaData &pkg, themepackages) {
-        m_plasmathemes << pkg.pluginId();
-    }
-
     m_categories = QStringList() << "all" \
         << "actions"
         << "animations"
@@ -143,12 +126,12 @@ void IconModel::add(const QFileInfo &info, const QString &cat)
     const QString fname = info.fileName();
     bool scalable = false;
     QString icon = fname;
-    if (fname.endsWith(".png")) {
+    if (fname.endsWith(QLatin1String(".png"))) {
         icon.remove(".png");
-    } else if (fname.endsWith(".svgz")) {
+    } else if (fname.endsWith(QLatin1String(".svgz"))) {
         icon.remove(".svgz");
         scalable = true;
-    } else if (fname.endsWith(".svg")) {
+    } else if (fname.endsWith(QLatin1String(".svg"))) {
         icon.remove(".svg");
         scalable = true;
     }
@@ -184,40 +167,11 @@ void IconModel::add(const QFileInfo &info, const QString &cat)
     }
 }
 
-QString IconModel::category() const
-{
-    return m_category;
-}
-
 QStringList IconModel::categories() const
 {
     return m_categories;
 }
 
-void IconModel::setCategory(const QString& cat)
-{
-    if (cat != m_category) {
-        m_category = cat;
-        emit categoryChanged();
-    }
-}
-
-QString IconModel::filter() const
-{
-    return m_filter;
-}
-
-void IconModel::setFilter(const QString &filter)
-{
-    //qDebug() << "Filter: " << filter;
-    if (m_filter != filter) {
-        m_filter = filter;
-        load();
-        emit filterChanged();
-        emit svgIconsChanged();
-    }
-}
-
 void IconModel::load()
 {
     //qDebug() << "\n -- Loading (category / filter) : " << m_category << m_filter;
@@ -253,7 +207,6 @@ void IconModel::load()
     }
 
     foreach (const QString &iconPath, searchPaths) {
-
         QDirIterator cats(iconPath, nameFilters, QDir::Dirs, QDirIterator::NoIteratorFlags);
         while (cats.hasNext()) {
             cats.next();
@@ -264,122 +217,18 @@ void IconModel::load()
                 while (it.hasNext()) {
                     it.next();
                     const QFileInfo &info = it.fileInfo();
-                    if (matchIcons(info)) {
-                        add(info, categoryFromPath(info.absoluteFilePath()));
-                    }
+                    add(info, categoryFromPath(info.absoluteFilePath()));
                 }
             }
         }
     }
 
-    svgIcons();
-
-    sort();
-
     endResetModel();
-    
+
     m_loading = false;
     emit loadingChanged();
 }
 
-void IconModel::sort()
-{
-    std::sort(m_icons.begin(), m_icons.end());
-}
-
-bool IconModel::matchIcons(const QFileInfo& info)
-{
-    bool ok = false;
-
-    // Category is empty or all? Skip further matching.
-    bool catmatch = m_category.isEmpty() || m_category == QStringLiteral("all");
-    // category match?
-    if (!catmatch && m_category == categoryFromPath(info.absoluteFilePath())) {
-        catmatch = true;
-    }
-
-    // name filter
-    if (m_filter.isEmpty() || info.fileName().indexOf(m_filter) != -1) {
-        if (catmatch) {
-            ok = true;
-        }
-    }
-    return ok;
-}
-
-
-QStringList IconModel::themes() const
-{
-    return m_themes;
-}
-
-QString IconModel::theme() const
-{
-    return m_theme;
-}
-
-void IconModel::setTheme(const QString& theme)
-{
-    if (theme != m_theme) {
-        m_theme = theme;
-        load();
-        emit themeChanged();
-    }
-}
-
-QString IconModel::plasmaTheme() const
-{
-    return m_plasmatheme;
-}
-
-void IconModel::setPlasmaTheme(const QString& ptheme)
-{
-    if (m_plasmatheme != ptheme) {
-        m_plasmatheme = ptheme;
-        Plasma::Theme theme;
-        theme.setThemeName(ptheme);
-        load();
-        emit plasmaThemeChanged();
-    }
-}
-
-QStringList IconModel::plasmathemes() const
-{
-    return m_plasmathemes;
-}
-
-void IconModel::svgIcons()
-{
-    QVariantList out;
-
-    foreach (const QString &file, m_svgIcons.keys()) {
-        foreach (const QString &icon, m_svgIcons[file].toStringList()) {
-            if (m_filter.isEmpty() ||
-               (file.indexOf(m_filter) != -1 || icon.indexOf(m_filter) != -1)) {
-
-                QVariantMap &data = m_data[icon];
-                if (!m_icons.contains(icon)) {
-
-                    data["fullPath"] = "";
-                    data["iconName"] = icon;
-                    data["fileName"] = file;
-                    data["category"] = "system";
-                    data["type"] = QStringLiteral("svg");
-                    data["scalable"] = true;
-                    data["iconTheme"] = m_plasmatheme;
-
-                    m_icons << icon;
-                }
-                QVariantMap vm;
-                vm["fileName"] = file;
-                vm["iconName"] = icon;
-                out << vm;
-            }
-        }
-    }
-    sort();
-}
-
 QString IconModel::categoryFromPath(const QString& path)
 {
     QStringList cats;
